==> jc-1.4.0.tar.gz: polyglot/frontend/SourceLoader.h <==
// public class polyglot.frontend.SourceLoader

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c0bff66c4ab313ae polyglot_frontend_SourceLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_SourceLoader_H_
#define _JC_polyglot_frontend_SourceLoader_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_FileSource$object;

// Typedefs
typedef struct _jc_polyglot_frontend_SourceLoader$sub_refs	_jc_polyglot_frontend_SourceLoader$sub_refs;
typedef struct _jc_polyglot_frontend_SourceLoader$sub_nonrefs	_jc_polyglot_frontend_SourceLoader$sub_nonrefs;
typedef struct _jc_polyglot_frontend_SourceLoader$refs	_jc_polyglot_frontend_SourceLoader$refs;
typedef struct _jc_polyglot_frontend_SourceLoader$nonrefs	_jc_polyglot_frontend_SourceLoader$nonrefs;
typedef struct _jc_polyglot_frontend_SourceLoader$object	_jc_polyglot_frontend_SourceLoader$object;

typedef struct _jc_polyglot_frontend_SourceLoader$fields_struct	_jc_polyglot_frontend_SourceLoader$fields_struct;
typedef const struct _jc_polyglot_frontend_SourceLoader$vmethods	_jc_polyglot_frontend_SourceLoader$vmethods;
typedef const struct _jc_polyglot_frontend_SourceLoader$vtable	_jc_polyglot_frontend_SourceLoader$vtable;
typedef const struct _jc_polyglot_frontend_SourceLoader$vtype	_jc_polyglot_frontend_SourceLoader$vtype;

// Class fields structure
struct _jc_polyglot_frontend_SourceLoader$fields_struct {
	struct _jc_java_io_File$object	*current__5fdir;
};
extern _jc_polyglot_frontend_SourceLoader$fields_struct _jc_polyglot_frontend_SourceLoader$class_fields;

// Constructors
extern void _jc_polyglot_frontend_SourceLoader$method$_init$3561e6eb5fac231a(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_polyglot_frontend_FileSource$object *_jc_polyglot_frontend_SourceLoader$method$classSource$9e78960aad0987c2(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *);
extern struct _jc_polyglot_frontend_FileSource$object *_jc_polyglot_frontend_SourceLoader$method$fileSource$7884cd4a1c97af23(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_SourceLoader$method_info$classSource$9e78960aad0987c2;
extern _jc_method _jc_polyglot_frontend_SourceLoader$method_info$fileSource$7884cd4a1c97af23;

// Static methods
extern void _jc_polyglot_frontend_SourceLoader$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_frontend_SourceLoader$vmethods {
	struct _jc_polyglot_frontend_FileSource$object	*(*classSource$9e78960aad0987c2)(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *);
	struct _jc_polyglot_frontend_FileSource$object	*(*fileSource$7884cd4a1c97af23)(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_polyglot_frontend_SourceLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_SourceLoader$vmethods	polyglot_frontend_SourceLoader;
};

// Vtype
struct _jc_polyglot_frontend_SourceLoader$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_SourceLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceLoader$sub_refs {
	struct _jc_object	*sourceExt;
	struct _jc_object	*sourcePath;
	struct _jc_object	*directoryContentsCache;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_SourceLoader$refs {
    _jc_polyglot_frontend_SourceLoader$sub_refs	polyglot_frontend_SourceLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_SourceLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_SourceLoader$sub_nonrefs	polyglot_frontend_SourceLoader;
};

// Object instance structure
struct _jc_polyglot_frontend_SourceLoader$object {
	_jc_polyglot_frontend_SourceLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_SourceLoader$vtype	*vtype;
	_jc_polyglot_frontend_SourceLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_SourceLoader$vtype _jc_polyglot_frontend_SourceLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_SourceLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_SourceLoader$class_object;

#endif	/* _JC_polyglot_frontend_SourceLoader_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/SourceLoader.h <==
// public class polyglot.frontend.SourceLoader

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c0bff66c4ab313ae polyglot_frontend_SourceLoader

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_frontend_SourceLoader_H_
#define _JC_polyglot_frontend_SourceLoader_H_

// Forward structure declarations
struct _jc_java_io_File$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_Map$object;
struct _jc_polyglot_frontend_ExtensionInfo$object;
struct _jc_polyglot_frontend_FileSource$object;

// Typedefs
typedef struct _jc_polyglot_frontend_SourceLoader$sub_refs	_jc_polyglot_frontend_SourceLoader$sub_refs;
typedef struct _jc_polyglot_frontend_SourceLoader$sub_nonrefs	_jc_polyglot_frontend_SourceLoader$sub_nonrefs;
typedef struct _jc_polyglot_frontend_SourceLoader$refs	_jc_polyglot_frontend_SourceLoader$refs;
typedef struct _jc_polyglot_frontend_SourceLoader$nonrefs	_jc_polyglot_frontend_SourceLoader$nonrefs;
typedef struct _jc_polyglot_frontend_SourceLoader$object	_jc_polyglot_frontend_SourceLoader$object;

typedef struct _jc_polyglot_frontend_SourceLoader$fields_struct	_jc_polyglot_frontend_SourceLoader$fields_struct;
typedef const struct _jc_polyglot_frontend_SourceLoader$vmethods	_jc_polyglot_frontend_SourceLoader$vmethods;
typedef const struct _jc_polyglot_frontend_SourceLoader$vtable	_jc_polyglot_frontend_SourceLoader$vtable;
typedef const struct _jc_polyglot_frontend_SourceLoader$vtype	_jc_polyglot_frontend_SourceLoader$vtype;

// Class fields structure
struct _jc_polyglot_frontend_SourceLoader$fields_struct {
	struct _jc_java_io_File$object	*current__5fdir;
};
extern _jc_polyglot_frontend_SourceLoader$fields_struct _jc_polyglot_frontend_SourceLoader$class_fields;

// Constructors
extern void _jc_polyglot_frontend_SourceLoader$method$_init$3561e6eb5fac231a(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_polyglot_frontend_FileSource$object *_jc_polyglot_frontend_SourceLoader$method$classSource$9e78960aad0987c2(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_polyglot_frontend_FileSource$object *_jc_polyglot_frontend_SourceLoader$method$fileSource$7884cd4a1c97af23(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_SourceLoader$method_info$classSource$9e78960aad0987c2;
extern _jc_method _jc_polyglot_frontend_SourceLoader$method_info$fileSource$7884cd4a1c97af23;

// Static methods
extern void _jc_polyglot_frontend_SourceLoader$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_frontend_SourceLoader$vmethods {
	struct _jc_polyglot_frontend_FileSource$object	*(*classSource$9e78960aad0987c2)(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_polyglot_frontend_FileSource$object	*(*fileSource$7884cd4a1c97af23)(_jc_env *, struct _jc_polyglot_frontend_SourceLoader$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_SourceLoader$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_SourceLoader$vmethods	polyglot_frontend_SourceLoader;
};

// Vtype
struct _jc_polyglot_frontend_SourceLoader$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_SourceLoader$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceLoader$sub_refs {
	struct _jc_object	*sourceExt;
	struct _jc_object	*sourcePath;
	struct _jc_object	*directoryContentsCache;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_SourceLoader$refs {
    _jc_polyglot_frontend_SourceLoader$sub_refs	polyglot_frontend_SourceLoader;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_SourceLoader$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_SourceLoader$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_SourceLoader$sub_nonrefs	polyglot_frontend_SourceLoader;
};

// Object instance structure
struct _jc_polyglot_frontend_SourceLoader$object {
	_jc_polyglot_frontend_SourceLoader$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_SourceLoader$vtype	*vtype;
	_jc_polyglot_frontend_SourceLoader$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_SourceLoader$vtype _jc_polyglot_frontend_SourceLoader$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_SourceLoader, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_SourceLoader$class_object;

#endif	/* _JC_polyglot_frontend_SourceLoader_H_ */
